package v1

import (
	"property-household-gateway/param/base"
	"property-household-gateway/pb/v1"
)

// 欠费线上缴费
type ChargeBillPayByHouseholdBody struct {
	BillIds []int64 `form:"bill_ids" json:"bill_ids"`
	// 绑定关系id列表
	BindIds []int64 `form:"bind_ids" json:"bind_ids"`
	// 应缴
	ShouldPayAmount int64 `form:"should_pay_amount" json:"should_pay_amount"`
	// 实缴
	PayAmount int64 `form:"pay_amount" json:"pay_amount"`
	// 备注
	Comment  string `form:"comment" json:"comment"`
	GardenId int64  `form:"garden_id" json:"garden_id"`
}

type ChargeBillPayByHouseholdRequest struct {
	base.Header
	ChargeBillPayByHouseholdBody
}

type ChargeBillPayByHouseholdResponse struct {
	base.Result
	Data v1.ChargeBillPayByHouseholdReply `json:"data"`
}

// 生活缴费代缴费和待支付
type ChargeUnpayListQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	HouseId  int64 `form:"house_id" json:"house_id"`
}

type ChargeUnpayListRequest struct {
	base.Header
	ChargeUnpayListQuery
}

type ChargeUnpayListResponse struct {
	base.Result
	Data v1.ChargeUnpayListReply `json:"data"`
}

// 查看费用，费项列表
type ChargeListQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	// 对象id
	ObjId int64 `form:"obj_id" json:"obj_id"`
	// 对象类型
	ObjType    int32 `form:"obj_type" json:"obj_type"`
	Page       int64 `form:"page" json:"page"`
	PageSize   int64 `form:"page_size" json:"page_size"`
	ChargeType int32 `form:"charge_type" json:"charge_type"`
}

type ChargeListRequest struct {
	base.Header
	ChargeListQuery
}

type ChargeListResponse struct {
	base.Result
	Data v1.ChargeListReply `json:"data"`
}

// 对象的某费项下的待缴账单列表
type ChargeBillListQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	BindId   int64 `form:"bind_id" json:"bind_id"`
}

type ChargeBillListRequest struct {
	base.Header
	ChargeBillListQuery
}

type ChargeBillListResponse struct {
	base.Result
	Data v1.ChargeBillListReply `json:"data"`
}

// 预缴物业费或车位费前获取对应的金额信息
type ChargePrePayInfoQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	BindId   int64 `form:"bind_id" json:"bind_id"`
	// 月数
	Months int64 `form:"months" json:"months"`
}

type ChargePrePayInfoRequest struct {
	base.Header
	ChargePrePayInfoQuery
}
type ChargePrePayInfoResponse struct {
	base.Result
	Data v1.ChargePrePayInfoReply `json:"data"`
}

type ChargePropertyMonthInfoQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	HouseId  int64 `form:"house_id" json:"house_id"`
}
type ChargePropertyMonthInfoRequest struct {
	base.Header
	ChargePropertyMonthInfoQuery
}
type ChargePropertyMonthInfoResponse struct {
	base.Result
	Data v1.ChargeMonthInfoReply `json:"data"`
}

type ChargeSpaceMonthInfoQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	SpaceId  int64 `form:"space_id" json:"space_id"`
}
type ChargeSpaceMonthInfoRequest struct {
	base.Header
	ChargeSpaceMonthInfoQuery
}
type ChargeSpaceMonthInfoResponse struct {
	base.Result
	Data v1.ChargeMonthInfoReply `json:"data"`
}

type ChargeVehicleMonthInfoQuery struct {
	GardenId  int64 `form:"garden_id" json:"garden_id"`
	VehicleId int64 `form:"vehicle_id" json:"vehicle_id"`
}
type ChargeVehicleMonthInfoRequest struct {
	base.Header
	ChargeVehicleMonthInfoQuery
}
type ChargeVehicleMonthInfoResponse struct {
	base.Result
	Data v1.ChargeMonthInfoReply `json:"data"`
}

// 线上预缴
type ChargePrePayByHouseholdBody struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	BindId   int64 `form:"bind_id" json:"bind_id"`
	Months   int64 `form:"months" json:"months"`
	// 应缴金额
	ShouldPayAmount int64 `form:"should_pay_amount" json:"should_pay_amount"`
	// 实缴金额
	PayAmount int64 `form:"pay_amount" json:"pay_amount"`
	// 套餐id
	PackageId int64 `form:"package_id" json:"package_id"`
}

type ChargePrePayByHouseholdRequest struct {
	base.Header
	ChargePrePayByHouseholdBody
}

type ChargePrePayByHouseholdResponse struct {
	base.Result
	Data v1.ChargePrePayByHouseholdReply `json:"data"`
}

// 缴费订单列表
type ChargeOrderListQuery struct {
	Page     int64 `form:"page,proto3" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type ChargeOrderListRequest struct {
	base.Header
	ChargeOrderListQuery
}

type ChargeOrderListResponse struct {
	base.Result
	Data v1.ChargeOrderListReply `json:"data"`
}

// 缴费订单详情
type ChargeOrderInfoQuery struct {
	GardenId int64  `form:"garden_id" json:"garden_id"`
	OrderId  string `form:"order_id" json:"order_id"`
}
type ChargeOrderInfoRequest struct {
	base.Header
	ChargeOrderInfoQuery
}

type ChargeOrderInfoResponse struct {
	base.Result
	Data v1.ChargeOrderInfoReply `json:"data"`
}

// 取消支付
type ChargeOrderCancelBody struct {
	GardenId int64  `form:"garden_id" json:"garden_id"`
	OrderId  string `form:"order_id" json:"order_id"`
	// true 未支付订单中用户主动取消，false 前端判断未支付时主动调接口删除
	ByUser bool `form:"by_user" json:"by_user"`
}
type ChargeOrderCancelRequest struct {
	base.Header
	ChargeOrderCancelBody
}

type ChargeOrderCancelResponse struct {
	base.Result
}

type ChargePayedBillListQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	HouseId  int64 `form:"house_id" json:"house_id"`
	PayTime  int64 `form:"pay_time" json:"pay_time"`
}

type ChargePayedBillListRequest struct {
	base.Header
	ChargePayedBillListQuery
}

type ChargePayedBillListResponse struct {
	base.Result
	Data v1.ChargePayedBillListReply `json:"data"`
}

type ChargeWxPayTestBody struct {
	PayAmount int64 `form:"pay_amount" json:"pay_amount"`
}
type ChargeWxPayTestRequest struct {
	base.Header
	ChargeWxPayTestBody
}

type ChargeWxPayTestResponse struct {
	base.Result
	Data v1.WxAppletPrepayReply `json:"data"`
}
