package v1

import (
	"property-household-gateway/param/base"
	pb_v1 "property-household-gateway/pb/v1"
)

type NeighborClassListQuery struct {
	GardenId  int64  `form:"garden_id" json:"garden_id"`
	Page      int64  `form:"page" json:"page"`
	PageSize  int64  `form:"page_size" json:"page_size"`
	ClassName string `form:"class_name" json:"class_name"`
}

type NeighborClassListRequest struct {
	base.Header
	NeighborClassListQuery
}

type NeighborClassListResponse struct {
	base.Result
	Data pb_v1.NeighborClassListReply `json:"data"`
}

type NeighborArticleAddBody struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	// 文章标题
	Title string `form:"title" json:"title"`
	// 文章类容
	Content string `form:"content" json:"content"`
	// 文章图片
	Pics []string `form:"pics" json:"pics"`
	// 分类id
	ClassId int64 `protobuf:"varint,5,opt,name=class_id,json=classId,proto3" json:"class_id"`
	//Uid                  int64    `protobuf:"varint,6,opt,name=uid,proto3" json:"uid"`
	//UserIcon             string   `protobuf:"bytes,7,opt,name=user_icon,json=userIcon,proto3" json:"user_icon"`
}

type NeighborArticleAddRequest struct {
	base.Header
	NeighborArticleAddBody
}

type NeighborArticleAddResponse struct {
	base.Result
}

type NeighborArticleUpdateBody struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	// 文章标题
	Title string `form:"title" json:"title"`
	// 文章类容
	Content string `form:"content" json:"content"`
	// 文章图片
	Pics []string `form:"pics" json:"pics"`
	Id   int64    `form:"id" json:"id"`
}

type NeighborArticleUpdateRequest struct {
	base.Header
	NeighborArticleUpdateBody
}

type NeighborArticleUpdateResponse struct {
	base.Result
}

type NeighborArticleDelQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	Id       int64 `form:"id" json:"id"`
}

type NeighborArticleDelRequest struct {
	base.Header
	NeighborArticleDelQuery
}

type NeighborArticleDelResponse struct {
	base.Result
}

type NeighborArticleListQuery struct {
	GardenId int64  `form:"garden_id" json:"garden_id"`
	Page     int64  `form:"page" json:"page"`
	PageSize int64  `form:"page_size" json:"page_size"`
	Title    string `form:"title" json:"title"`
	IsMe     bool   `form:"is_me" json:"is_me"`
}

type NeighborArticleListRequest struct {
	base.Header
	NeighborArticleListQuery
}

type NeighborArticleListResponse struct {
	base.Result
	Data pb_v1.NeighborArticleListReply `json:"data"`
}

type NeighborCommentAddBody struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	// 文章类容
	Content string `form:"content" json:"content"`
	// 文章图片
	Pics []string `form:"pics" json:"pics"`
	// pid 和 article_id 二选一， 当为文章评论使用article_id, 当为评论添加子评论使用pid(即父评论id)
	Pid       int64 `form:"pid" json:"pid"`
	ArticleId int64 `form:"article_id" json:"article_id"`
}

type NeighborCommentAddRequest struct {
	base.Header
	NeighborCommentAddBody
}

type NeighborCommentAddResponse struct {
	base.Result
}

type NeighborCommentUpdateBody struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	// 文章类容
	Content string `form:"content" json:"content"`
	// 文章图片
	Pics []string `form:"pics" json:"pics"`
	Id   int64    `form:"id" json:"id"`
}

type NeighborCommentUpdateRequest struct {
	base.Header
	NeighborCommentUpdateBody
}

type NeighborCommentUpdateResponse struct {
	base.Result
}

type NeighborCommentDelQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	Id       int64 `form:"id" json:"id"`
}

type NeighborCommentDelRequest struct {
	base.Header
	NeighborCommentDelQuery
}

type NeighborCommentDelResponse struct {
	base.Result
}

type NeighborCommentListQuery struct {
	GardenId  int64 `form:"garden_id" json:"garden_id"`
	Page      int64 `form:"page" json:"page"`
	PageSize  int64 `form:"page_size" json:"page_size"`
	Pid       int64 `form:"pid" json:"pid"`
	ArticleId int64 `form:"article_id" json:"article_id"`
}

type NeighborCommentListRequest struct {
	base.Header
	NeighborCommentListQuery
}

type NeighborCommentListResponse struct {
	base.Result
	Data pb_v1.NeighborCommentListReply `json:"data"`
}

type NeighborLikeBody struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	// 点赞id(like_type为1时代表文章id，like_type为2时代表评论id)
	LikeId int64 `form:"like_id" json:"like_id"`
	// 点赞类型 1 文章 2 评论
	LikeType int32 `form:"like_type" json:"like_type"`
	// true 点赞 false 撤销点赞(前端应做相应控制，如果目标已点赞则不能点赞只能撤销，如果目标未点赞则只能点赞，不能撤销)
	Like bool `form:"like" json:"like"`
}

type NeighborLikeRequest struct {
	base.Header
	NeighborLikeBody
}

type NeighborLikeResponse struct {
	base.Result
}
