package v1

import (
	"property-household-gateway/param/base"
	"property-household-gateway/pb/v1"
)


type RepairClassListQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
	Page                 int64    `form:"page" json:"page"`
	PageSize             int64    `form:"page_size" json:"page_size"`
	Area int32 `form:"area"`
}

type RepairClassListRequest struct{
	base.Header
	RepairClassListQuery
}

type RepairClassListResponse struct{
	base.Result
	Data v1.RepairClassListReply `json:"data"`
}



type RepairOrderAddBody struct {
	// 分类id
	ClassId int64 `form:"class_id" json:"class_id"`
	// 报修人
	ApplyPeople string `form:"apply_people" json:"apply_people"`
	// 报修人电话
	ApplyPeoplePhone string `form:"apply_people_phone" json:"apply_people_phone"`
	// 预约时间
	Appointment int64 `form:"appointment" json:"appointment"`
	// 房屋id
	HouseId int64 `form:"house_id" json:"house_id"`

	GardenId int64 `form:"garden_id" json:"garden_id"`

	// 报修内容
	ApplyContent string `form:"apply_content" json:"apply_content"`
	// 报修图片
	ApplyPic             []string `form:"apply_pic" json:"apply_pic"`
}

type RepairOrderAddRequest struct {
	base.Header
	RepairOrderAddBody
}

type RepairOrderAddResponse struct{
	base.Result
	Data v1.RepairOrderAddReply `json:"data"`
}

type RepairOrderUpdateBody struct {
	// 分类id
	ClassId int64 `form:"class_id" json:"class_id"`
	// 报修人
	ApplyPeople string `form:"apply_people" json:"apply_people"`
	// 报修人电话
	ApplyPeoplePhone string `form:"apply_people_phone" json:"apply_people_phone"`
	// 预约时间
	Appointment int64 `form:"appointment" json:"appointment"`
	// 房屋id
	HouseId int64 `form:"house_id" json:"house_id"`
	// 报修内容
	ApplyContent string `form:"apply_content" json:"apply_content"`
	// 报修图片
	ApplyPic             []string `form:"apply_pic" json:"apply_pic"`
	GardenId int64 `form:"garden_id" json:"garden_id"`
	Id int64 `form:"id"`
}


type RepairOrderUpdateRequest struct{
	base.Header
	RepairOrderUpdateBody
}

type RepairOrderUpdateResponse struct{
	base.Result
}

type RepairOrderDelQuery struct {
	Id int64 `form:"id"`
	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type RepairOrderDelRequest struct{
	base.Header
	RepairOrderDelQuery
}

type RepairOrderDelResponse struct{
	base.Result
}

type RepairOrderListQuery struct {
	Page                 int64    `form:"page" json:"page"`
	PageSize             int64    `form:"page_size" json:"page_size"`
	Status               int32    `form:"status" json:"status"`
	ApplyPeople          string   `form:"apply_people" json:"apply_people"`
	ApplyPeoplePhone     string   `form:"apply_people_phone" json:"apply_people_phone"`
	ClassId              int64    `form:"class_id" json:"class_id"`
	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type RepairOrderListRequest struct{
	base.Header
	RepairOrderListQuery
}

type RepairOrderListResponse struct{
	base.Result
	Data v1.RepairOrderListReply `json:"data"`
}

type RepairOrderInfoQuery struct {
	Id int64 `form:"id"`
	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type RepairOrderInfoRequest struct{
	base.Header
	RepairOrderInfoQuery
}

type RepairOrderInfoResponse struct{
	base.Result
	Data v1.RepairOrderInfoReply `json:"data"`
}



type RepairOrderReturnVisitBody struct {
	Id                   int64    `form:"id" json:"id"`
	// 1 满意 2 不满意
	ReturnVisitLevel int32 `form:"return_visit_level" json:"return_visit_level"`
	// 回访内容
	ReturnVisitContent   string   `form:"return_visit_content" json:"return_visit_content"`
	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type RepairOrderReturnVisitRequest struct{
	base.Header
	RepairOrderReturnVisitBody
}

type RepairOrderReturnVisitResponse struct{
	base.Result
}


