// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"property-household-gateway/param/base"
	"property-household-gateway/pb/v1"
)

type HouseholdHousesQuery struct {
	ForRent bool `form:"for_rent" json:"for_rent"`
}
type HouseholdHousesRequest struct {
	base.Header
	HouseholdHousesQuery
}

type HouseholdHousesResponse struct {
	base.Result
	Data v1.HouseholdHousesReply `json:"data"`
}

type HouseholdSpaceQuery struct {
	UserType int32 `form:"user_type" json:"user_type"`
	HouseId  int64 `form:"house_id" json:"house_id"`
	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type HouseholdSpaceRequest struct {
	base.Header
	HouseholdSpaceQuery
}

type HouseholdSpaceResponse struct {
	base.Result
	Data v1.ParkSpaceListReply `json:"data"`
}

type HouseholdVehicleQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type HouseholdVehicleRequest struct {
	base.Header
	HouseholdVehicleQuery
}

type HouseholdVehicleResponse struct {
	base.Result
	Data v1.VehicleListReply `json:"data"`
}

type LoginBody struct {
	Code string `form:"code"`
	// 手机号加密数据
	PhoneEncrypt string `form:"phone_encrypt" json:"phone_encrypt"`
	// 用户信息加密数据
	UserEncrypt string `form:"user_encrypt" json:"user_encrypt"`
	// 手机号加密初始向量
	PhoneIv string `form:"phone_iv" json:"phone_iv"`
	// 用户信息加密初始向量
	UserIv string `form:"user_iv" json:"user_iv"`
}

type LoginRequest struct {
	base.Header
	LoginBody
}

type LoginData struct {
	Uid    int64  `json:"uid"`
	Token  string `json:"token"`
	User   string `json:"user"`
	OpenId string `json:"open_id"`
	Phone  string `json:"phone"`
	// 头像
	Avatar   string `json:"avatar"`
	OpenimId string `json:"openim_id"`
	NickName string `json:"nick_name"`
}

type LoginResponse struct {
	base.Result
	Data LoginData `json:"data"`
}

type TokenRequest struct {
	base.Header
}

type TokenResponse struct {
	base.Result
	Data         string `json:"data"`
	RefreshToken string `json:"refresh_token"`
}

type RealNameAuthBody struct {
	RealName string `form:"real_name" json:"real_name"`
	IdType   int32  `form:"id_type" json:"id_type"`
	IdNumber string `form:"id_number" json:"id_number"`
}

type RealNameAuthRequest struct {
	base.Header
	RealNameAuthBody
}

type RealNameAuthData struct {
	Token string
}
type RealNameAuthResponse struct {
	base.Result
	Data RealNameAuthData `json:"data"`
}

type UserUpdateNickNameBody struct {
	NickName string `form:"nick_name" json:"nick_name"`
}

type UserUpdateNickNameRequest struct {
	base.Header
	UserUpdateNickNameBody
}

type UserUpdateNickNameResponse struct {
	base.Result
}

type UserInfoRequest struct {
	base.Header
}
type UserInfoResponse struct {
	base.Result
	Data v1.UserInfoReply `json:"data"`
}

type OpenImTokenQuery struct {
	OpenimId string `form:"openim_id" json:"openim_id"`
}

type OpenImTokenRequest struct {
	base.Header
	OpenImTokenQuery
}

type OpenImTokenResponse struct {
	base.Header
	Data v1.OpenImTokenReply `json:"data"`
}

type OpenImUsersInfoQuery struct {
	OpenimIds string `form:"openim_ids" json:"openim_ids"`
}

type OpenImUsersInfoRequest struct {
	base.Header
	OpenImUsersInfoQuery
}

type OpenImUsersInfoResponse struct {
	base.Result
	Data v1.OpenImUserInfoReply `json:"data"`
}
